using System;
using System.Collections.Generic;
using System.Text;
using System.Net.Mail;
namespace EmailLogger
{
    /// <summary>
    /// This is used to send a simple email. 
    /// Inspired by SmtpTask at: http://channel9.msdn.com/wiki/default.aspx/MSBuild.ExtendMSBuildWithANewTask
    /// <author>Sayed Ibrahim Hashimi (sayed.hashimi@gmail.com) 2/07/2005</author>
    /// </summary>
    public class Emailer
    {
        #region
        private string smtpHost;
        private string from;
        private string to;
        private string cc;
        private int smtpPort;
        private int timeOut;
        private string subject;
        private string body;
        private string attachment;
        #endregion

        public Emailer()
        {
            timeOut = 30 * 1000;
            smtpHost = "";
            from = "";
            to = "";
            cc = "";
            smtpPort = -1;
            subject = "";
            body = "";
            attachment = "";
        }

        #region Public Properties/methods
        public string SmtpHost
        {
            get
            {
                return this.smtpHost;
            }
            set
            {
                this.smtpHost = value;
            }
        }
        public string From
        {
            get 
            {
                return this.from;
            }
            set
            {
                this.from = value;
            }
        }
        public string To
        {
            get
            {
                return this.to;
            }
            set
            {
                this.to = value;
            }
        }
        public string Cc
        {
            get
            {
                return this.cc;
            }
            set
            {
                this.cc = value;
            }
        }
        public int SmtpPort
        {
            get
            {
                return this.smtpPort;
            }
            set
            {
                this.smtpPort = value;
            }
        }
        public void SetSmtpPort(string smtpPortString)
        {
            if (string.IsNullOrEmpty(smtpPortString))
            {
                return;
            }

            this.smtpPort = Int32.Parse(smtpPortString);
        }
        public int Timeout
        {
            get
            {
                return this.timeOut;
            }
            set
            {
                this.timeOut = value;
            }
        }
        public void SetTimeout(string timeoutString)
        {
            if (string.IsNullOrEmpty(timeoutString))
            {
                return;
            }

            this.timeOut = Int32.Parse(timeoutString);
        }
        public string Subject
        {
            get
            {
                return this.subject;
            }
            set
            {
                this.subject = value;
            }
        }
        public string Body
        {
            get
            {
                return this.body;
            }
            set
            {
                this.body = value;
            }
        }
        public string Attachment
        {
            get
            {
                return this.attachment;
            }
            set
            {
                this.attachment = value;
            }
        }
        #endregion

        /// <summary>
        /// Method to call to send the email after properties have been set
        /// <returns>false if email was not sent out</returns>
        /// </summary>
        public bool SendEmail()
        {
            //make sure that we have all the necessary properties to send the email
            if (string.IsNullOrEmpty(SmtpHost) ||
                string.IsNullOrEmpty(To) ||
                string.IsNullOrEmpty(Body))
            {
                return false;
            }

            //now send the email out
            MailMessage message = new MailMessage();
            message.From = new MailAddress(this.From);
            foreach(string toEntry in this.To.Split(";".ToCharArray(),StringSplitOptions.RemoveEmptyEntries) )
            {
                message.To.Add(toEntry);
            }
            foreach (string ccEntry in this.Cc.Split(";".ToCharArray(), StringSplitOptions.RemoveEmptyEntries))
            {
                message.CC.Add(ccEntry);
            }
            foreach (string attachEntry in this.Attachment.Split(";".ToCharArray(), StringSplitOptions.RemoveEmptyEntries))
            {
                message.Attachments.Add( new Attachment(attachEntry.Trim()));
            }

            message.Subject = this.Subject;
            message.Body = this.Body;

            SmtpClient smtpClient = new SmtpClient(this.SmtpHost);
            smtpClient.Timeout = this.Timeout;

            if (this.SmtpPort > 0)
            {
                smtpClient.Port = SmtpPort;
            }

            smtpClient.Send(message);

            return true;
        }

        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();

            sb.Append("[");
            sb.Append("SmtpHost:");
            sb.Append(SmtpHost);
            sb.Append(" From:");
            sb.Append(From);
            sb.Append(" To:");
            sb.Append(To);
            sb.Append(" CC:");
            sb.Append(Cc);
            sb.Append(" SmptPort:");
            sb.Append(SmtpPort);
            sb.Append(" Timeout:");
            sb.Append(Timeout);
            sb.Append(" Subject:");
            sb.Append(Subject);
            sb.Append(" Body:");
            sb.Append(Body);
            sb.Append(" Attachement:");
            sb.Append(Attachment);
            sb.Append("]");

            return sb.ToString();
        }
    
    
    }
}
